@@ -516,6 +516,8 @@ class Cursor(Base):
 
     time = Attribute(types=int, required=True, default=lambda: int(time.time()))
     limit = Attribute(types=int)
+    serial = Attribute(types=str, coerce=str)
+    direction = Attribute(types=str, required=True, default='DESC')
 
     def __init__(self, row=None, **kw):
         if row is None:
@@ -538,6 +540,8 @@ class Cursor(Base):
         elif row is None:
             row = {}
 
+        row = copy.copy(row)
+        row['limit'] = self._force_limit(row.get('limit', None))
         self.list = []
 
         super().__init__(row, **kw)
@@ -569,31 +573,6 @@ class Cursor(Base):
             return 1
         return limit
 
-class CursorExt(Cursor):
-    serial = Attribute(types=str, coerce=str)
-    direction = Attribute(types=str, required=True, default='DESC')
-
-    def __init__(self, row = None, **kw):
-        if row is None:
-            row = {}
-        if isinstance(row, CursorExt):
-            row = row.pure_python()
-
-        if isinstance(row, str):
-            data = unpack(TOKEN, row)
-
-            if data is None:
-                row = {}
-            elif isinstance(data, dict):
-                row = data.get('cursor', {})
-            else:
-                row = {}
-
-        row = copy.copy(row)
-        row['limit'] = self._force_limit(row.get('limit', None))
-
-        super().__init__(row, **kw)
-
 
 class BaseModel(Base):
     """ Base model """
@@ -760,12 +739,12 @@ class BaseModel(Base):
 
         elif cursor is not None or by == 'cursor':
             tmp = 'cursor.sqlt'
-            cursor = CursorExt(cursor or kw)
+            cursor = Cursor(cursor or kw)
             kw['cursor'] = cursor
 
         else:
             tmp = 'full.sqlt'
-            cursor = CursorExt(kw)
+            cursor = Cursor(kw)
 
         sql, args = sqlt(tmp, kw)
 
@@ -807,6 +786,29 @@ class BaseModel(Base):
 
         return cursor.list, cursor.cursor_str
 
+    @classmethod
+    async def fetch(
+        cls,
+        by,
+        **kw,
+    ):
+        """ RAW request """
+
+        db = cls.get_db()
+        kw = {
+            **kw,
+            'table': cls.meta.table,
+            'sqlbase': cls.sqlbase(),
+            'shard': db.get('shard'),
+        }
+
+        sql, args = sqlt(f'{by}.sqlt', kw)
+
+        async with dbh(**db) as conn:
+            data = await conn.fetch(sql, *args)
+
+        return data
+
     async def reload(self, **kw):
         """ Update the instance according to the data from the DB
 
